<?php
// Additional functions used by the wpsub plugin



// Use this function if you'd like to insert sliding box into your templates, loops, etc.
function wpsub_slideupbox ( $arr ) {

	if ( !isset( $arr["mode"] ) ) {
		$arr["mode"] = 'bottom-up-full';
	}

	$shortcode = '[slideupbox';

	foreach ( $arr as $key => $value ) {
		$shortcode .= ' ' . $key . '="' . $value . '"';
	}

	$shortcode .= ']';

	echo do_shortcode( $shortcode );

}



// Function for select mode
function wpsub_select_mode( $is_array = false ) {

	$modes = array (
		"bottom-up-full",
		"bottom-up-part",
		"left-right",
		"left-right-uncover",
		"right-left",
		"right-left-uncover",
		"fade-in",
		"fade-out",
		"top-down-full",
		"top-down-part",
	);

	if ( $is_array ) {
		$options = array();

		foreach ( $modes as $mode ) {
			$options[$mode] = $mode;
		}

		return $options;
	}

	else {

		$options = '';
		$default_values = tpl_get_value( array( 'name' => 'wpsub_default_vaules') );

		foreach ( $modes as $mode ) {
			if ( $default_values["mode"] == $mode ) {
				$options .= '<option selected="selected" value="' . $mode . '">' . $mode . '</option>';
			}

			else {
				$options .= '<option value="' . $mode . '">' . $mode . '</option>';
			}
		}

		return $options;

	}

}



// Function that return with image sizes in option tags or with an associative array
function wpsub_image_sizes( $is_array = false ) {

	if ( $is_array ) {
		$sizes = array();

		foreach ( get_intermediate_image_sizes() as $size ) {
			$sizes[$size] = $size;
		}

		return $sizes;
	}

	else {
		$sizes = '';
		$default_values = tpl_get_value( array( 'name' => 'wpsub_default_vaules') );

		foreach ( get_intermediate_image_sizes() as $size ) {
			if ( $default_values["size"] == $size ) {
				$sizes .= '<option selected="selected" value="' . $size . '">' . $size . '</option>';
			}

			else {
				$sizes .= '<option value="' . $size . '">' . $size . '</option>';
			}
		}

		return $sizes;
	}

}



// This function handles the admin page of the plugin
function wpsub_shortcode_generator() {

	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.', 'wpsub' ) );
	}

	$default_values = tpl_get_value( 'wpsub_default_vaules' );

	$return = '<div class="wrap">
		<h2>' . __( 'a-boxes (WP Slide-up box)', 'wpsub' ) . '</h2>

		<div id="wpsub-addnewe">
			<h3>' . __( 'Shortcode Generator', 'wpsub' ) . '</h3>
			<form name="wpsub_addnew" method="post" action="' . $_SERVER["REQUEST_URI"] . '">
			<table class="wpsub_formtable">
				<tr>
					<td>' . __( 'Image ID or URL*', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_imgid" id="wpsub_imgid" value="' . $default_values["image"] . '" /></td>
				</tr>
				<tr>
					<td>' . __( 'Mode', 'wpsub' ) . ':</td><td>
						<select name="wpsub_mode" id="wpsub_mode">' .
							wpsub_select_mode()
						. '</select>
					</td>
				</tr>
				<tr>
					<td>' . __( 'Title text', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_title" id="wpsub_title" value="' . $default_values["title"] . '"/></td>
				</tr>
				<tr>
					<td>' . __( 'Description', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_desc" id="wpsub_desc" value="' . $default_values["description"] . '"/></td>
				</tr>
				<tr>
					<td>' . __( 'Target URL', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_target" id="wpsub_target" value="' . $default_values["url"] . '"/></td>
				</tr>
				<tr>
					<td>' . __( 'Extra class', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_class" id="wpsub_class" value="' . $default_values["class"] . '"/></td>
				</tr>
				<tr>
					<td>' . __( 'Cover background color', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_bg_color" id="wpsub_bg_color" class="tpl-color-field tpl-preview-0" data-default-color="' . esc_attr( $default_values["bgcolor"] ) . '" value="' . $default_values["bgcolor"] . '"/></td>
				</tr>
				<tr>
					<td>' . __( 'Cover text color', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_text_color" id="wpsub_text_color" class="tpl-color-field tpl-preview-0" data-default-color="' . esc_attr( $default_values["color"] ) . '" value="' . $default_values["color"] . '"/></td>
				</tr>
				<tr>
					<td>' . __( 'Image alt text', 'wpsub' ) . ':</td><td><input type="text" name="wpsub_alt" id="wpsub_alt" value="' . $default_values["alt"] . '"/></td>
				</tr>
				<tr id="wpsub-size-row">
					<td>' . __( 'Size', 'wpsub' ) . ':</td><td>
						<select name="wpsub_size" id="wpsub_size">' .
							wpsub_image_sizes()
						. '</select>
					</td>
				</tr>
				<tr>
					<td></td><td><input id="wpsub-generate" type="submit" value="' . __( 'Generate shortcode', 'wpsub' ) . '" /></td>
				</tr>
			</table>
			</form>

			<div id="shortcode-wrapper"></div>
		</div>

		<div id="wpsub-generator-tabs">
			<ul>
				<li><a href="#wpsub-preview">' . __( 'Preview', 'wpsub' ) . '</a></li>
				<li><a href="#wpsub-hints">' . __( 'Usage', 'wpsub' ) . '</a></li>
			</ul>

			<div id="wpsub-preview">
				<h2>' . __( 'Preview', 'wpsub' ) . '</h2>
				<p>' . __( 'Press the <strong>Generate Shortcode</strong> button on the left to update the Preview.', 'wpsub' ) . '</p>
				<div id="preview-wrapper"></div>
			</div>

			<div id="wpsub-hints">
				<h2>' . __( 'Usage', 'wpsub' ) . '</h2>
				<ol>
					<li>' . __( 'Use the Shortcode generator form on this page', 'wpsub' ) . '</li>
					<li>' . __( 'Clicking on the Generate shortcode button will create the shortcode for you', 'wpsub' ) . '</li>
					<li>' . __( 'Copy the shortcode from here and paste it into the post or page you\'d like to use it in', 'wpsub' ) . '</li>
				</ol>
				<h3>' . __( 'A quick explanation about the different attributes', 'wpsub' ) . ':</h3>
				<ul>
					<li><strong>id:</strong> ' . __( 'The attachment ID or the URL of the image. This is the only required field. <a href="https://a-idea.studio/blog/find-id-number-picture-wordpress/" target="_blank">Click here for a tutorial on how to find it.</a> Alternatively you can use the image URL here, too.', 'wpsub' ) . '</li>
					<li><strong>mode:</strong> ' . __( 'The animation type for the box. To understand better how the different modes work, take a look at our <a href="https://a-idea.studio/a-boxes/modes-showcase/" target="_blank">Modes Showcase</a> page.', 'wpsub' ) . '</li>
					<li><strong>title:</strong> ' . __( 'The text displayed on the top of the box.', 'wpsub' ) . '</li>
					<li><strong>desc:</strong> ' . __( 'The smaller text at the bottom part of the box. If you want to place a link in it use the next shorttag: {{link|http://www.example.com}}. (before the | goes the anchor text and after it the URL)', 'wpsub' ) . '</li>
					<li><strong>target:</strong> ' . __( 'The URL the box should be linked to.', 'wpsub' ) . '</li>
					<li><strong>class:</strong> ' . __( 'You can add extra classes to the box container with it.', 'wpsub' ) . '</li>
					<li><strong>bgcolor:</strong> ' . __( 'The background color of the cover layer.', 'wpsub' ) . '</li>
					<li><strong>color:</strong> ' . __( 'The text color of the cover layer.', 'wpsub' ) . '</li>
					<li><strong>alt:</strong> ' . __( 'Alternative text for the background image. If not set, the title will be used.', 'wpsub' ) . '</li>
					<li><strong>size:</strong> ' . __( 'Size of the image (defined with WordPress image sizes). Works only if "id" is a number.', 'wpsub' ) . '</li>
				</ul>
				<p>' . __( 'For detiled tutorials and full documentation, <a href="https://a-idea.studio/a-boxes/" target="_blank">visit the plugin\'s official pages</a>.', 'wpsub' ) . '</p>
			</div>
		</div>

	</div>';

	echo $return;

}



// Support page in admin
function wpsub_support() {

	// Content for the Support page
	$support_text = __( '<h2>' . __( 'a-boxes Support', 'wpsub' ) . '</h2>
		<hr>
		<h4><span class="dashicons dashicons-book-alt"></span> ' . __( 'Documentation', 'wpsub' ) . '</h4>
		<p>' . __( 'You can find the <b>a-boxes</b> plugin\'s online documentation here', 'wpsub' ) . ': <a href="https://a-idea.studio/a-boxes/" target="_blank">' . __( 'a-boxes Documentation', 'wpsub' ) . '</a></p>
		<h4><span class="dashicons dashicons-format-chat"></span> ' . __( 'Online Support', 'wpsub' ) . '</h4>
		<p>' . __( 'Have a question about the usage of the plugin? Have an idea about what could be included in the next version?', 'wpsub' ) . ' <a href="https://a-idea.studio/a-boxes/comments-and-suggestions/" target="_blank">' . __( 'Tell us about it!', 'wpsub' ) . '</a></p>
		<h4><span class="dashicons dashicons-star-filled"></span> ' . __( 'Rate us on Wordpress.org', 'wpsub' ) . '</h4>
		<p>' . __( 'It\'s only one click, but means a lot for us if you <a href="https://wordpress.org/support/plugin/a-boxes/reviews/" target="_blank">leave a review on the <b>a-boxes</b> plugin</a> Thank you!', 'wpsub' ) . '</p>
		<h4><span class="dashicons dashicons-tagcloud"></span> ' . __( 'Add your site to our Wall of Fame', 'wpsub' ) . '</h4>
		<p>' . __( 'Are you proud of your site where you use this plugin? Apply for a place on our Wall of Fame page', 'wpsub' ) . ': <a href="https://a-idea.studio/wall-of-fame/" target="_blank">' . __( 'Read more', 'wpsub' ) . '</a></p>
		<h4><span class="dashicons dashicons-admin-plugins"></span> ' . __( 'Try our other plugins, too', 'wpsub' ) . '</h4>
		<p><a href="https://a-idea.studio/products/" target="_blank">' . __( 'Click here to see all our plugins', 'wpsub' ) . '</a></p>
		<h4><span class="dashicons dashicons-thumbs-up"></span> ' . __( 'Get Social, like us', 'wpsub' ) . ':</h4>
		<p><a class="tpl-nodecor" href="https://twitter.com/aidea_studio" target="_blank"><span class="dashicons dashicons-twitter"></span> Twitter</a></p>
		<p><a class="tpl-nodecor" href="https://www.facebook.com/aidea.webdesign.studio/" target="_blank"><span class="dashicons dashicons-facebook"></span> Facebook</a></p>
	', 'wpsub' );

	echo $support_text;

}



// Handling of Preview AJAX call
function wpsub_preview_ajax() {

	if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
		echo do_shortcode( stripslashes( $_POST["shortcode"] ) );
	}

	die();

}
add_action( 'wp_ajax_wpsub_ajax_shortcode', 'wpsub_preview_ajax' );
