<?php
// Setting up the options for the wpsub plugin



// Adding the WPSUB Settings page to WP-Admin
function wpsub_settings_page( $pages ) {

	$pages["wpsub_settings"] = array(
		"page_title"	=> __( 'a-boxes (WP Slide-up box)', 'wpsub' ),
		"menu_title"	=> __( 'a-boxes', 'wpsub' ),
		"capability"	=> 'manage_options',
		"menu_slug"		=> 'wpsub_settings',
		"function"		=> 'wpsub_settings',
		"post_type"		=> 'wpsub_settings',
		"menu_func"		=> 'add_menu_page'
	);

	return $pages;

}
add_filter( 'tpl_settings_pages', 'wpsub_settings_page', 10, 1 );



// Add plugin-specific sections and options
add_action( 'init', 'wpsub_setup', 30 );

function wpsub_setup() {

	global $tpl_load_version;

	// Dont'd do anything if our version of Themple Framework is lower than the required
	if ( version_compare( $tpl_load_version["version"], WPSUB_REQ_TPL_VERSION ) < 0 ) {
		return;
	}


	add_filter( 'tpl_before_register_option', 'wpsub_disable_less_variables' );


	// First set up the required sections


	// Section for the wpsub general settings
	$section = array (
		"name"			=> 'wpsub_general_settings',
		"tab"			=> __( 'Settings', 'wpsub' ),
		"title"			=> __( 'General settings', 'wpsub' ),
		"description"	=> __( 'Basic settings for slide up boxes', 'wpsub' ),
		"post_type"		=> 'wpsub_settings',
	);
	tpl_register_section ( $section );



	// And now the options inside the sections

	/* SETTINGS */

	$image_sizes = wpsub_image_sizes( true );
	$animation_modes = wpsub_select_mode( true );

	// Default values
	$tpl_option_array = array (
		"name"			=> 'wpsub_default_vaules',
		"title"			=> __( 'Default values', 'wpsub' ),
		"description"	=> __( 'Set your default values for the shortcode generator', 'wpsub' ),
		"section"		=> 'wpsub_general_settings',
		"type"			=> 'combined',
		"js"			=> true,
		"parts"			=> array(
			array(
				"name"          => 'image',
				"title"			=> __( 'Image', 'wpsub' ),
				"description"	=> __( 'Image url or id', 'wpsub' ),
				"type"			=> 'text',
				"default"		=> '',
			),
			array(
				"name"			=> 'mode',
				"title"			=> __( 'Mode', 'wpsub' ),
				"description"	=> __( 'The animation type for the box.', 'wpsub' ),
				"type"			=> 'select',
				"values"		=> $animation_modes,
				"default"		=> 'bottom-up-full',
			),
			array(
				"name"          => 'title',
				"title"			=> __( 'Title text', 'wpsub' ),
				"description"	=> __( 'The text displayed on the top of the box', 'wpsub' ),
				"type"			=> 'text',
				"default"		=> '',
			),
			array(
				"name"          => 'description',
				"title"			=> __( 'Description', 'wpsub' ),
				"description"	=> __( 'The longer text at the bottom part of the box.', 'wpsub' ),
				"type"			=> 'text',
				"default"		=> '',
			),
			array(
				"name"			=> 'url',
				"title"			=> __( 'Target URL', 'wpsub' ),
				"description"	=> __( 'The URL the box should be linked to.', 'wpsub' ),
				"type"			=> 'text',
				"default"		=> '',
			),
			array(
				"name"			=> 'class',
				"title"			=> __( 'Extra class', 'wpsub' ),
				"description"	=> __( ' You can add extra classes to the box container with it.', 'wpsub' ),
				"type"			=> 'text',
				"default"		=> '',
			),
			array(
				"name"			=> 'bgcolor',
				"title"			=> __( 'Background color', 'wpsub' ),
				"description"	=> __( 'Set the cover background color', 'wpsub' ),
				"type"			=> 'color',
				"default"		=> '#000000',
			),
			array(
				"name"			=> 'color',
				"title"			=> __( 'Font color', 'wpsub' ),
				"description"	=> __( 'Set the cover font color', 'wpsub' ),
				"type"			=> 'color',
				"default"		=> '#ffffff',
			),
			array(
				"name"			=> 'alt',
				"title"			=> __( 'Alt text', 'wpsub' ),
				"description"	=> __( 'Alternative text for the background image', 'wpsub' ),
				"type"			=> 'text',
				"default"		=> '',
			),
			array(
				"name"			=> 'size',
				"title"			=> __( 'Size', 'wpsub' ),
				"description"	=> __( 'Size of the image (defined with WordPress image sizes).', 'wpsub' ),
				"type"			=> 'select',
				"values"		=> $image_sizes,
			),
		),
	);
	tpl_register_option ( $tpl_option_array );



	remove_filter( 'tpl_before_register_option', 'wpsub_disable_less_variables' );

}



// With this function we disable the plugin's options to be parsed into a Themple-based theme's LESS variables. This way we eliminate possible fatal errors. Can be removed in the future.
function wpsub_disable_less_variables( $narr = array() ) {
	$narr["less"] = false;
	return $narr;
}
